# odvc

Ocean Dimensionless Vertical Coordinates

CAVEAT: this package is not ready for production use!

The `formulas.py` works also as a guide on how to code the CF Ocean Dimensionless Vertical Coordinates in Python,
while `utils.py` contains a few handy functions to use the formulas with dask arrays.

For more information on how to integrate this into your project see the iris package vertical coordinates.
